@@ -1,5 +1,5 @@
 package Linux::Statm::Tiny;
-$Linux::Statm::Tiny::VERSION = '0.0503';
+
 use Moo;
 use MooX::Aliases;
 
@@ -8,7 +8,7 @@ use POSIX qw/ ceil /;
 use Types::Standard qw/ ArrayRef Int /;
 
 {
-    $Linux::Statm::Tiny::VERSION = '0.0503'
+    $Linux::Statm::Tiny::VERSION = '0.0504'
 }
 
 =head1 NAME
@@ -251,6 +251,6 @@ merchantability or fitness for a particular purpose.
 
 =cut
 
-use namespace::sweep;
+use namespace::autoclean 0.16;
 
 1;
